# PySwyft

PySwyft is a Python Wrapper for the [Swyftx](https://swyftx.com/) API

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install PySwyft.

```bash
pip install pyswyft
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## About this software
The PySwyft software is a personal project. I have no prior or existing relationship with Swyftx.

If you have any questions regarding this software, please take a look at the documentation first:

Swyftx developer docs : https://docs.swyftx.com.au/
Github: https://github.com/MrTeale/PySwyft check the open and closed issues
If you still have questions/issues you can open an issue on Gitub: https://github.com/MrTeale/PySwyft